@@ -1,6 +1,8 @@
 from redis import StrictRedis
 import sys
-from SettingService import Redis
+
+sys.path.append('../../')
+from inhand.service.SettingService import Redis
 
 class CacheService:
     def __init__(self,settings):
